@@ -13,6 +13,20 @@ def SVDO(so2_mat):
     S_dash[1,1] = np.linalg.det(U@VT)
     return U@S_dash@VT
 
+def identity():
+    return np.identity(2)
+
+def perturb_local(so2_mat, theta):
+    theta = float(theta)
+    return so2_mat@Exp(theta)
+
+def perturb_global(so2_mat, theta):
+    theta = float(theta)
+    return Exp(theta)@so2_mat
+
+
+    
+
 
 def inv(so2_mat):
     assert se2_mat.shape == (2,2)
